You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2019/08/08 13:45:37 UTC

[commons-io] branch master updated: Javadoc: Use the same names for arguments as the JDK, less confusing.

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-io.git


The following commit(s) were added to refs/heads/master by this push:
     new 84484f2  Javadoc: Use the same names for arguments as the JDK, less confusing.
84484f2 is described below

commit 84484f26cd1de6073f8ab36fbf7b2e48e00d75e4
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Thu Aug 8 09:45:34 2019 -0400

    Javadoc: Use the same names for arguments as the JDK, less confusing.
---
 .../org/apache/commons/io/output/ProxyWriter.java   | 21 ++++++++++-----------
 1 file changed, 10 insertions(+), 11 deletions(-)

diff --git a/src/main/java/org/apache/commons/io/output/ProxyWriter.java b/src/main/java/org/apache/commons/io/output/ProxyWriter.java
index 469c401..67c97e8 100644
--- a/src/main/java/org/apache/commons/io/output/ProxyWriter.java
+++ b/src/main/java/org/apache/commons/io/output/ProxyWriter.java
@@ -27,7 +27,6 @@ import java.io.Writer;
  * to increase reusability, because FilterWriter changes the
  * methods being called, such as write(char[]) to write(char[], int, int)
  * and write(String) to write(String, int, int).
- *
  */
 public class ProxyWriter extends FilterWriter {
 
@@ -107,14 +106,14 @@ public class ProxyWriter extends FilterWriter {
 
     /**
      * Invokes the delegate's <code>write(int)</code> method.
-     * @param idx the character to write
+     * @param c the character to write
      * @throws IOException if an I/O error occurs
      */
     @Override
-    public void write(final int idx) throws IOException {
+    public void write(final int c) throws IOException {
         try {
             beforeWrite(1);
-            out.write(idx);
+            out.write(c);
             afterWrite(1);
         } catch (final IOException e) {
             handleIOException(e);
@@ -144,16 +143,16 @@ public class ProxyWriter extends FilterWriter {
 
     /**
      * Invokes the delegate's <code>write(char[], int, int)</code> method.
      * @param chr the characters to write
      * @param st The start offset
      * @param len The number of characters to write
      * @throws IOException if an I/O error occurs
      */
     @Override
-    public void write(final char[] chr, final int st, final int len) throws IOException {
+    public void write(final char[] cbuf, final int off, final int len) throws IOException {
         try {
             beforeWrite(len);
-            out.write(chr, st, len);
+            out.write(cbuf, off, len);
             afterWrite(len);
         } catch (final IOException e) {
             handleIOException(e);
@@ -184,15 +183,15 @@ public class ProxyWriter extends FilterWriter {
     /**
      * Invokes the delegate's <code>write(String)</code> method.
      * @param str the string to write
      * @param st The start offset
      * @param len The number of characters to write
      * @throws IOException if an I/O error occurs
      */
     @Override
-    public void write(final String str, final int st, final int len) throws IOException {
+    public void write(final String str, final int off, final int len) throws IOException {
         try {
             beforeWrite(len);
-            out.write(str, st, len);
+            out.write(str, off, len);
             afterWrite(len);
         } catch (final IOException e) {
             handleIOException(e);
@@ -144,16 +143,16 @@ public class ProxyWriter extends FilterWriter {
     /**
      * Invokes the delegate's <code>write(char[], int, int)</code> method.
-     * @param chr the characters to write
-     * @param st The start offset
+     * @param cbuf the characters to write
+     * @param off The start offset
      * @param len The number of characters to write
      * @throws IOException if an I/O error occurs
@@ -184,15 +183,15 @@ public class ProxyWriter extends FilterWriter {
      * Invokes the delegate's <code>write(String)</code> method.
      * @param str the string to write
-     * @param st The start offset
+     * @param off The start offset
      * @param len The number of characters to write
      * @throws IOException if an I/O error occurs